@@ -1,31 +1,27 @@
-
-# MAPLAT  (C) 2008-2009 Rene Schickbauer
+# MAPLAT  (C) 2008-2010 Rene Schickbauer
 # Developed under Artistic license
 # for Magna Powertrain Ilz
-
 package Maplat::Helpers::Mascot;
-
-use 5.008000;
 use strict;
 use warnings;
 
-require Exporter;
+use 5.008000;
 
-our @ISA = qw(Exporter);
-our @EXPORT= qw(Mascot);
+use base qw(Exporter);
+our @EXPORT= qw(Mascot); ## no critic
 
-our $VERSION = 0.970;
+our $VERSION = 0.98;
 
 our @lines;
 
-sub Mascot() {
-	
-	# Only on first call, read in DATA segment
-	if(!defined($lines[1])) {
-		@lines = <DATA>;
-	}
-	
-	return \@lines;
+sub Mascot {
+    
+    # Only on first call, read in DATA segment
+    if(!defined($lines[1])) {
+        @lines = <DATA>;
+    }
+    
+    return \@lines;
 }
 
 1;
@@ -51,11 +47,11 @@ This prints out a cute little rabbit, the mascot of the Maplat project.
 
 =head1 AUTHOR
 
-Rene Schickbauer, E<lt>rene.schickbauer@magnapowertrain.comE<gt>
+Rene Schickbauer, E<lt>rene.schickbauer@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 by Rene Schickbauer
+Copyright (C) 2008-2010 by Rene Schickbauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
