@@ -1,19 +1,16 @@
-
-# MAPLAT  (C) 2008-2009 Rene Schickbauer
+# MAPLAT  (C) 2008-2010 Rene Schickbauer
 # Developed under Artistic license
 # for Magna Powertrain Ilz
-
-
 package Maplat::Web::MemCacheSim;
-use Maplat::Web::BaseModule;
-@ISA = ('Maplat::Web::BaseModule');
+use strict;
+use warnings;
+
+use base qw(Maplat::Web::BaseModule);
 use Maplat::Helpers::DateStrings;
 use Maplat::Helpers::BuildNum;
 
-our $VERSION = 0.970;
+our $VERSION = 0.98;
 
-use strict;
-use warnings;
 use Maplat::Helpers::Cache::Memcached;
 use Carp;
 
@@ -24,16 +21,16 @@ sub new {
     my $self = $class->SUPER::new(%config); # Call parent NEW
     bless $self, $class; # Re-bless with our class
 
-	$self->{mctype} = "sim";
-	
-	# Add version information about our to the memcached storage
-	# for the rare cases we need that for other programs to run
-	# a compatibility API or something
-	# APPNAME and VERSION in main needs to be declared "our ..."
-	$self->set("VERSION::" . $main::APPNAME, $main::VERSION);
-	$self->set("BUILD::" . $main::APPNAME, readBuildNum());
+    $self->{mctype} = "sim";
+    
+    # Add version information about our to the memcached storage
+    # for the rare cases we need that for other programs to run
+    # a compatibility API or something
+    # APPNAME and VERSION in main needs to be declared "our ..."
+    $self->set("VERSION::" . $main::APPNAME, $main::VERSION);
+    $self->set("BUILD::" . $main::APPNAME, readBuildNum());
 
-	$self->{oldtime} = 0;
+    $self->{oldtime} = 0;
 
     my %memd = ();
     $self->{memd} = \%memd;
@@ -43,35 +40,37 @@ sub new {
 
 sub reload {
     my ($self) = shift;
+    return;
 }
 
 sub register {
     my $self = shift;
-	$self->register_task("refresh_lifetick");
+    $self->register_task("refresh_lifetick");
+    return;
 }
 
 sub refresh_lifetick {
-	my ($self) = @_;
-	
-	my $ticktime = time;
-	
-	if(($ticktime - $self->{oldtime}) > 10) {
-		# only refresh every 10 seconds or so to keep
-		# resource usage low - otherwise we'd be setting
-		# the lifetick 1000 times a second or so
-		my $tickkey = "LIFETICK::" . $$;
-		$self->set($tickkey, $ticktime);
-		$self->{oldtime} = $ticktime;
-		return 1;
-	}
-	return 0;
+    my ($self) = @_;
+    
+    my $ticktime = time;
+    
+    if(($ticktime - $self->{oldtime}) > 10) {
+        # only refresh every 10 seconds or so to keep
+        # resource usage low - otherwise we'd be setting
+        # the lifetick 1000 times a second or so
+        my $tickkey = "LIFETICK::" . $$;
+        $self->set($tickkey, $ticktime);
+        $self->{oldtime} = $ticktime;
+        return 1;
+    }
+    return 0;
 }
 
 sub get {
-	my ($self, $key) = @_;
-	
-	$key = $self->sanitize_key($key);
-	
+    my ($self, $key) = @_;
+    
+    $key = $self->sanitize_key($key);
+    
     if(defined($self->{memd}->{$key})) {
         return $self->{memd}->{$key};
     } else {
@@ -80,54 +79,55 @@ sub get {
 }
 
 sub set {
-	my ($self, $key, $data) = @_;
+    my ($self, $key, $data) = @_;
 
-	$key = $self->sanitize_key($key);
-	
-	return $self->{memd}->{$key} =  $data;
+    $key = $self->sanitize_key($key);
+    
+    return $self->{memd}->{$key} =  $data;
 }
 
-sub delete {
-	my ($self, $key) = @_;
-	
-	$key = $self->sanitize_key($key);
-	
-	delete $self->{memd}->{$key};
+sub delete {## no critic(BuiltinHomonyms)
+    my ($self, $key) = @_;
+    
+    $key = $self->sanitize_key($key);
+    
+    delete $self->{memd}->{$key};
     return 1;
 }
 
 sub sanitize_key {
-	my ($self, $key) = @_;
-	
-	# Certain chars are not allowed in keys for whatever reason.
-	# This *should* be handled by the Cache::Memcached module, but isn't
-	# We handle this by substituting them with a tripple underline
-	
-	$key =~ s/\ /___/go;
-	
-	return $key;
+    my ($self, $key) = @_;
+    
+    # Certain chars are not allowed in keys for whatever reason.
+    # This *should* be handled by the Cache::Memcached module, but isn't
+    # We handle this by substituting them with a tripple underline
+    
+    $key =~ s/\ /___/go;
+    
+    return $key;
 }
 
 # Helpers for "active commands"
 sub set_activecommand {
-	my ($self, $commandid) = @_;
-	
-	$self->set($main::APPNAME . "::activecommand", $commandid);
+    my ($self, $commandid) = @_;
+    
+    $self->set($main::APPNAME . "::activecommand", $commandid);
+    return;
 }
 
 sub get_activecommands {
-	my ($self) = @_;
-	
-	my %commands;
-	
-	foreach my $cmd (@{$self->{viewcommands}->{view}}) {
-		my $value = $self->get($cmd . "::activecommand");
-		if(defined($value) && $value ne "0") {
-			$commands{$value} = $cmd;
-		}
-	}
-	
-	return %commands;
+    my ($self) = @_;
+    
+    my %commands;
+    
+    foreach my $cmd (@{$self->{viewcommands}->{view}}) {
+        my $value = $self->get($cmd . "::activecommand");
+        if(defined($value) && $value ne "0") {
+            $commands{$value} = $cmd;
+        }
+    }
+    
+    return %commands;
 }
 
 1;
@@ -243,11 +243,11 @@ Maplat::Web
 
 =head1 AUTHOR
 
-Rene Schickbauer, E<lt>rene.schickbauer@magnapowertrain.comE<gt>
+Rene Schickbauer, E<lt>rene.schickbauer@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 by Rene Schickbauer
+Copyright (C) 2008-2010 by Rene Schickbauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
