@@ -1,18 +1,15 @@
-
-# MAPLAT  (C) 2008-2009 Rene Schickbauer
+# MAPLAT  (C) 2008-2010 Rene Schickbauer
 # Developed under Artistic license
 # for Magna Powertrain Ilz
-
-
 package Maplat::Web::PathRedirection;
-use Maplat::Web::BaseModule;
-@ISA = ('Maplat::Web::BaseModule');
-
-our $VERSION = 0.970;
-
 use strict;
 use warnings;
 
+use base qw(Maplat::Web::BaseModule);
+
+our $VERSION = 0.98;
+
+
 use Carp;
 
 sub new {
@@ -43,11 +40,13 @@ sub new {
 
 sub reload {
     # Nothing to do
+    return;
 }
 
 sub register {
     my $self = shift;
     $self->register_prefilter("prefilter");
+    return;
 }
 
 sub prefilter {
@@ -121,11 +120,11 @@ Maplat::Web::BrowserWorksarounds
 
 =head1 AUTHOR
 
-Rene Schickbauer, E<lt>rene.schickbauer@magnapowertrain.comE<gt>
+Rene Schickbauer, E<lt>rene.schickbauer@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 by Rene Schickbauer
+Copyright (C) 2008-2010 by Rene Schickbauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
