@@ -1,19 +1,16 @@
-
-# MAPLAT  (C) 2008-2009 Rene Schickbauer
+# MAPLAT  (C) 2008-2010 Rene Schickbauer
 # Developed under Artistic license
 # for Magna Powertrain Ilz
-
-
 package Maplat::Web::Status;
-use Maplat::Web::BaseModule;
-@ISA = ('Maplat::Web::BaseModule');
-use Maplat::Helpers::DateStrings;
-
-our $VERSION = 0.970;
-
 use strict;
 use warnings;
 
+use base qw(Maplat::Web::BaseModule);
+use Maplat::Helpers::DateStrings;
+
+our $VERSION = 0.98;
+
+
 use Carp;
 
 sub new {
@@ -29,60 +26,62 @@ sub new {
 sub reload {
     my ($self) = shift;
     # Nothing to do.. in here, we only use the template and database module
+    return;
 }
 
 sub register {
     my $self = shift;
     $self->register_webpath($self->{webpath}, "get");
     $self->register_defaultwebdata("get_defaultwebdata");
+    return;
 }
 
 sub get {
     my ($self, $cgi) = @_;
 
-	my $dbh = $self->{server}->{modules}->{$self->{db}};
-	
-	# !!! Must work on form data before calling get_defaultwebdata, otherwise the header will be wrong
+    my $dbh = $self->{server}->{modules}->{$self->{db}};
+    
+    # !!! Must work on form data before calling get_defaultwebdata, otherwise the header will be wrong
     my $mode = $cgi->param('mode') || 'view';
-	if($mode ne "view") {
-		my @arguments;
-		my $insth;
-		my $command = "";
-		
-		my $delsth = $dbh->prepare_cached("DELETE FROM errors WHERE error_id = ? ");
+    if($mode ne "view") {
+        my @arguments;
+        my $insth;
+        my $command = "";
+        
+        my $delsth = $dbh->prepare_cached("DELETE FROM errors WHERE error_id = ? ");
 
-		if($mode eq "ackerror"){
-			my $error_id = $cgi->param('error_id') || '';
-			if($error_id ne "") {
-				$delsth->execute($error_id);
-				$delsth->finish;
-				$dbh->commit;
-			}
-		}
-	}
-	
+        if($mode eq "ackerror"){
+            my $error_id = $cgi->param('error_id') || '';
+            if($error_id ne "") {
+                $delsth->execute($error_id);
+                $delsth->finish;
+                $dbh->commit;
+            }
+        }
+    }
+    
     my %webdata = (
         $self->{server}->get_defaultwebdata(),
         PageTitle   =>  $self->{pagetitle},
-        PostLink	    =>  $self->{webpath}
+        PostLink        =>  $self->{webpath}
     );
     
-	my $errsth = $dbh->prepare_cached("SELECT error_id, reporttime, error_type, description " .
-							   "FROM errors " .
-							   "ORDER BY reporttime"
-								)
-					or die($dbh->errstr);
-	my @errors;
-	$errsth->execute or die($dbh->errstr);
-	while((my $errline = $errsth->fetchrow_hashref)) {
-		$errline->{error_image} = "rbserror_" . lc($errline->{error_type}) . ".bmp";
-		push @errors, $errline;
-	}
-	$errsth->finish;
+    my $errsth = $dbh->prepare_cached("SELECT error_id, reporttime, error_type, description " .
+                               "FROM errors " .
+                               "ORDER BY reporttime"
+                                )
+                    or croak($dbh->errstr);
+    my @errors;
+    $errsth->execute or croak($dbh->errstr);
+    while((my $errline = $errsth->fetchrow_hashref)) {
+        $errline->{error_image} = "rbserror_" . lc($errline->{error_type}) . ".bmp";
+        push @errors, $errline;
+    }
+    $errsth->finish;
     $webdata{errors} = \@errors;
-		
+        
     $dbh->rollback;
-	
+    
     my $template = $self->{server}->{modules}->{templates}->get("status", 1, %webdata);
     return (status  =>  404) unless $template;
     return (status  =>  200,
@@ -98,8 +97,8 @@ sub get_defaultwebdata {
     
     my $stmt = "SELECT count(*) FROM errors ";
     
-    my $sth = $dbh->prepare_cached($stmt) or die($dbh->errstr);
-    $sth->execute or die($dbh->errstr);
+    my $sth = $dbh->prepare_cached($stmt) or croak($dbh->errstr);
+    $sth->execute or croak($dbh->errstr);
     my $cnt = 0;
     while((my @line = $sth->fetchrow_array)) {
         $cnt = $line[0];
@@ -108,6 +107,7 @@ sub get_defaultwebdata {
     $dbh->rollback;
     
     $webdata->{rbs_urgentstatuscount} = $cnt;
+    return;
 }
 
 1;
@@ -156,11 +156,11 @@ Maplat::Web::PostgresDB
 
 =head1 AUTHOR
 
-Rene Schickbauer, E<lt>rene.schickbauer@magnapowertrain.comE<gt>
+Rene Schickbauer, E<lt>rene.schickbauer@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 by Rene Schickbauer
+Copyright (C) 2008-2010 by Rene Schickbauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
