@@ -1,20 +1,17 @@
-
-# MAPLAT  (C) 2008-2009 Rene Schickbauer
+# MAPLAT  (C) 2008-2010 Rene Schickbauer
 # Developed under Artistic license
 # for Magna Powertrain Ilz
-
-
 package Maplat::Web::VariablesADM;
-use Maplat::Web::BaseModule;
-@ISA = ('Maplat::Web::BaseModule');
+use strict;
+use warnings;
+
+use base qw(Maplat::Web::BaseModule);
 use Maplat::Helpers::DateStrings;
 
-our $VERSION = 0.970;
+our $VERSION = 0.98;
 
 # WARNING: This uses mainly hardcoded stuff
 
-use strict;
-use warnings;
 
 use Carp;
 
@@ -24,69 +21,71 @@ sub new {
     
     my $self = $class->SUPER::new(%config); # Call parent NEW
     bless $self, $class; # Re-bless with our class
-	
-	my @variables = qw[LogoDate HeaderMessage HeaderInfo];
-	$self->{variables} = \@variables;
-	
+    
+    my @variables = qw[LogoDate HeaderMessage HeaderInfo];
+    $self->{variables} = \@variables;
+    
     return $self;
 }
 
 sub reload {
     my ($self) = shift;
     # Nothing to do.. in here, we only use the template and database module
+    return;
 }
 
 sub register {
     my $self = shift;
     $self->register_webpath($self->{webpath}, "get");
+    return;
 }
 
 sub get {
     my ($self, $cgi) = @_;
     
     my $webpath = $cgi->path_info();
-	my $memh = $self->{server}->{modules}->{$self->{memcache}};
+    my $memh = $self->{server}->{modules}->{$self->{memcache}};
 
-	# Need to handle setting/deleting variables before getting the
-	# default webdata so changes take effect instantly
-	my $mode = $cgi->param('mode') || 'view';
-	
-	if($mode eq "setvalue") {
-		my $varname = $cgi->param('varname');
-		my $varvalue = $cgi->param('varvalue') || "";
-		my $setter = "set_$varname";
-		$self->$setter($varvalue);
-	} elsif($mode eq "delvalue") {
-		my $varname = $cgi->param('varname');
-		my $setter = "del_$varname";
-		$self->$setter;
-	} elsif($mode eq "reload") {
-		$self->{server}->reload;
-	}
+    # Need to handle setting/deleting variables before getting the
+    # default webdata so changes take effect instantly
+    my $mode = $cgi->param('mode') || 'view';
+    
+    if($mode eq "setvalue") {
+        my $varname = $cgi->param('varname');
+        my $varvalue = $cgi->param('varvalue') || "";
+        my $setter = "set_$varname";
+        $self->$setter($varvalue);
+    } elsif($mode eq "delvalue") {
+        my $varname = $cgi->param('varname');
+        my $setter = "del_$varname";
+        $self->$setter;
+    } elsif($mode eq "reload") {
+        $self->{server}->reload;
+    }
 
-	my %webdata =
-	(
-		$self->{server}->get_defaultwebdata(),
-	    PageTitle   	=>  $self->{pagetitle},
-	    webpath			=>  $self->{webpath},
-	);
-	
-	my @varlist;
-	foreach my $var (@{$self->{variables}}) {
-		my $getter = "get_$var";
-		my $val = $self->$getter;
-		if(!defined($val)) {
-			$val = "";
-		}
-		my %line = (
-			name	=> $var,
-			value	=> $val,
-		);
-		push @varlist, \%line;
-	}
-	$webdata{variables} = \@varlist;
-	
-	my $template = $self->{server}->{modules}->{templates}->get("variablesadm", 1, %webdata);
+    my %webdata =
+    (
+        $self->{server}->get_defaultwebdata(),
+        PageTitle       =>  $self->{pagetitle},
+        webpath            =>  $self->{webpath},
+    );
+    
+    my @varlist;
+    foreach my $var (@{$self->{variables}}) {
+        my $getter = "get_$var";
+        my $val = $self->$getter;
+        if(!defined($val)) {
+            $val = "";
+        }
+        my %line = (
+            name    => $var,
+            value    => $val,
+        );
+        push @varlist, \%line;
+    }
+    $webdata{variables} = \@varlist;
+    
+    my $template = $self->{server}->{modules}->{templates}->get("variablesadm", 1, %webdata);
     return (status  =>  404) unless $template;
     return (status  =>  200,
             type    => "text/html",
@@ -94,57 +93,63 @@ sub get {
 }
 
 sub set_LogoDate {
-	my ($self, $value) = @_;
-	
-	$self->{server}->{modules}->{logo}->{today} = $value;
+    my ($self, $value) = @_;
+    
+    $self->{server}->{modules}->{logo}->{today} = $value;
+    return;
 }
 
 sub get_LogoDate {
-	my ($self) = @_;
-	
-	return $self->{server}->{modules}->{logo}->{today};
+    my ($self) = @_;
+    
+    return $self->{server}->{modules}->{logo}->{today};
 }
 
 sub del_LogoDate {
-	my ($self) = @_;
-	
-	undef $self->{server}->{modules}->{logo}->{today};
+    my ($self) = @_;
+    
+    undef $self->{server}->{modules}->{logo}->{today};
+    return;
 }
 
 sub set_HeaderMessage {
-	my ($self, $value) = @_;
-	
-	$self->{server}->{modules}->{defaultwebdata}->{fields}->{header_message} = $value;
+    my ($self, $value) = @_;
+    
+    $self->{server}->{modules}->{defaultwebdata}->{fields}->{header_message} = $value;
+    return;
 }
 
 sub get_HeaderMessage {
-	my ($self) = @_;
-	
-	return $self->{server}->{modules}->{defaultwebdata}->{fields}->{header_message};
+    my ($self) = @_;
+    
+    return $self->{server}->{modules}->{defaultwebdata}->{fields}->{header_message};
 }
 
 sub del_HeaderMessage {
-	my ($self) = @_;
-	
-	undef $self->{server}->{modules}->{defaultwebdata}->{fields}->{header_message};
+    my ($self) = @_;
+    
+    undef $self->{server}->{modules}->{defaultwebdata}->{fields}->{header_message};
+    return;
 }
 
 sub set_HeaderInfo {
-	my ($self, $value) = @_;
-	
-	$self->{server}->{modules}->{defaultwebdata}->{fields}->{header_info} = $value;
+    my ($self, $value) = @_;
+    
+    $self->{server}->{modules}->{defaultwebdata}->{fields}->{header_info} = $value;
+    return;
 }
 
 sub get_HeaderInfo {
-	my ($self) = @_;
-	
-	return $self->{server}->{modules}->{defaultwebdata}->{fields}->{header_info};
+    my ($self) = @_;
+    
+    return $self->{server}->{modules}->{defaultwebdata}->{fields}->{header_info};
 }
 
 sub del_HeaderInfo {
-	my ($self) = @_;
-	
-	undef $self->{server}->{modules}->{defaultwebdata}->{fields}->{header_info};
+    my ($self) = @_;
+    
+    undef $self->{server}->{modules}->{defaultwebdata}->{fields}->{header_info};
+    return;
 }
 
 1;
@@ -232,11 +237,11 @@ Maplat::Web::Memcache
 
 =head1 AUTHOR
 
-Rene Schickbauer, E<lt>rene.schickbauer@magnapowertrain.comE<gt>
+Rene Schickbauer, E<lt>rene.schickbauer@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 by Rene Schickbauer
+Copyright (C) 2008-2010 by Rene Schickbauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
